Learn R Programming

gcxgclab (version 1.1.0)

TIC_integrate: TIC integration

Description

TIC_integrate calculates the total area under the TIC curve.

Usage

TIC_integrate(data, start_t = "first", end_t = "last")

Value

A float object. The calculated approximation of the area under the TIC curve.

Arguments

data

a list object. Data extracted from a cdf file, ideally the output from extract_data().

start_t

a float or string object. Value of starting time for integration range. Default is 'first' which will start at the initial time in the data.

end_t

a float or string object. Value of ending time for integration range. Default is 'last' which will start at the final time in the data.

Details

This function calculates the total area under the TIC curve using Simpson's Rule area approximation. Area given in 1 flattened time dimension.

Examples

Run this code
file <- system.file("extdata","sample1.cdf",package="gcxgclab")
frame <- extract_data(file,mod_t=.5)
sm_frame <- smooth(frame, lambda=10)
blc_frame <- bl_corr(sm_frame, gamma=0.5)
TIC_integrate(blc_frame)

Run the code above in your browser using DataLab